@@ -242,11 +242,47 @@ class Graph(Datastructure):
 
     @classmethod
     def from_networkx(cls, graph):
-        raise NotImplementedError
+        """Create a new graph instance from a NetworkX DiGraph instance.
+
+        Parameters
+        ----------
+        graph : networkx.DiGraph
+            NetworkX instance of a directed graph.
+
+        Returns
+        -------
+        Graph
+            A newly created graph.
+        """
+        g = cls()
+        g.attributes.update(graph.graph)
+
+        for node in graph.nodes():
+            g.add_node(node, **graph.nodes[node])
+
+        for edge in graph.edges():
+            g.add_edge(*edge, **graph.edges[edge])
+
+        return g
 
     def to_networkx(self):
+        """Create a new NetworkX graph instance from a graph.
+
+        Returns
+        -------
+        networkx.DiGraph
+            A newly created NetworkX DiGraph.
+        """
         import networkx as nx
-        graph = nx.Graph(self.edges())
+        graph = nx.DiGraph()
+        graph.graph.update(self.attributes)
+
+        for node, attr in self.nodes(data=True):
+            graph.add_node(node, **attr)
+
+        for edge, attr in self.edges(data=True):
+            graph.add_edge(*edge, **attr)
+
         return graph
 
     # --------------------------------------------------------------------------
@@ -477,24 +513,10 @@ class Graph(Datastructure):
             for v in list(self.edge[u]):
                 if v == key:
                     del self.edge[u][v]
-            if not self.edge[u]:
-                del self.edge[u]
         for u in self.adjacency:
             for v in list(self.adjacency[u]):
                 if v == key:
                     del self.adjacency[u][v]
-        # for nbr in self.neighbors(key):
-        #     del self.adjacency[key][nbr]
-        #     del self.adjacency[nbr][key]
-        #     if key in self.edge and nbr in self.edge[key]:
-        #         del self.edge[key][nbr]
-        #     else:
-        #         del self.edge[nbr][key]
-        #     if nbr == key:
-        #         del self.edge[nbr]
-        # del self.node[key]
-        # del self.adjacency[key]
-        # del self.edge[key]
 
     def delete_edge(self, u, v):
         """Delete an edge from the network.
@@ -514,7 +536,7 @@ class Graph(Datastructure):
         del self.adjacency[v][u]
         if u in self.edge and v in self.edge[u]:
             del self.edge[u][v]
-        else:
+        if v in self.edge and u in self.edge[v]:
             del self.edge[v][u]
 
     # --------------------------------------------------------------------------
@@ -684,10 +706,9 @@ class Graph(Datastructure):
 
         Yields
         ------
-        2-tuple
+        tuple
             The next edge identifier (u, v), if ``data`` is ``False``.
-        3-tuple
-            The next node as a (u, v, attr) tuple, if ``data`` is ``True``.
+            Otherwise, the next edge identifier and its attributes as a ((u, v), attr) tuple.
         """
         for u, nbrs in iter(self.edge.items()):
             for v, attr in iter(nbrs.items()):
@@ -711,10 +732,9 @@ class Graph(Datastructure):
 
         Yields
         ------
-        2-tuple
-            The next edge as a (u, v) tuple, if ``data=False``.
-        3-tuple
-            The next edge as a (u, v, data) tuple, if ``data=True``.
+        tuple
+            The next edge identifier (u, v), if ``data`` is ``False``.
+            Otherwise, the next edge identifier and its attributes as a ((u, v), attr) tuple.
         """
         for key in self.edges():
             is_match = True
@@ -759,17 +779,16 @@ class Graph(Datastructure):
         ----------
         predicate : callable
             The condition you want to evaluate.
-            The callable takes 3 parameters: ``u``, ``v``, ``attr`` and should return ``True`` or ``False``.
+            The callable takes 2 parameters: a key ``(u, v)`` tuple and ``attr`` and should return ``True`` or ``False``.
         data : bool, optional
             Yield the nodes and their data attributes.
             Default is ``False``.
 
         Yields
         ------
-        2-tuple
-            The next edge as a (u, v) tuple, if ``data=False``.
-        3-tuple
-            The next edge as a (u, v, data) tuple, if ``data=True``.
+        tuple
+            The next edge identifier (u, v), if ``data`` is ``False``.
+            Otherwise, the next edge identifier and its attributes as a ((u, v), attr) tuple.
 
         Examples
         --------
@@ -1407,9 +1426,9 @@ class Graph(Datastructure):
         u : hashable
             The identifier of the first node of the edge.
         v : hashable
-            The identifier of the secondt node of the edge.
+            The identifier of the second node of the edge.
         directed : bool, optional
-            Take into accoun the direction of the edge.
+            Take into account the direction of the edge.
             Default is ``True``.
 
         Returns
